<template>
  当前患者: {{patient?.patId}} {{isStringEmpty(patient?.patName)?'无':patient.patName}}
    <el-form
      ref="formRef"
      :model="formData"
      :rules="formRules"
      label-width="100px"
      v-loading="formLoading"
    >
      <el-form-item label="设备编号" prop="devId">
        <el-input v-model="formData.devId" placeholder="请输入设备编号" />
      </el-form-item>
      <el-form-item label="装机时间" prop="rentTime">
        <el-date-picker
          v-model="formData.rentTime"
          type="date"
          value-format="x"
          placeholder="选择装机时间"
        />
      </el-form-item>
      <el-form-item label="备注" prop="remark">
        <el-input v-model="formData.remark" placeholder="请输入备注" />
      </el-form-item>
    </el-form>
    <el-button @click="submitForm" type="primary" :disabled="formLoading">装机完成</el-button>
    <el-button @click="cancelInstall" type="primary" :disabled="formLoading">放弃装机</el-button>
    <el-button @click="resetForm()">重 置</el-button>


  <!-- 医生拆机列表 -->
  <ContentWrap>
    <el-table v-loading="loading" :data="list" :stripe="true" :show-overflow-tooltip="true" @current-change="onCurChange" >
      <el-table-column label="id" align="center" prop="id" />
      <el-table-column label="--" align="center" prop="cancelled" >
        <template #default="scope">
          {{scope.row.cancelled == 1 ? "放弃" : ""}}
        </template>
      </el-table-column>
<!--      <el-table-column label="作业类型" align="center" prop="jobType" />-->
<!--      <el-table-column label="医生编号" align="center" prop="docId" />-->
      <el-table-column label="医生名称" align="center" width="auto" prop="docName" />
      <el-table-column label="设备编号" align="center" prop="devId" />
<!--      <el-table-column label="患者编号" align="center" prop="patId" />-->
      <el-table-column label="患者名称" align="center" prop="patName" />
      <el-table-column
          label="作业时间"
          align="center"
          prop="jobTime"
          :formatter="timeFormatter"
      />
<!--      <el-table-column label="作业概要" align="center" prop="summary" />-->
      <el-table-column label="备注" align="center" prop="remark" />
<!--
      <el-table-column
          label="创建时间"
          align="center"
          prop="createTime"
          :formatter="dateFormatter"
      />
-->
<!--
      <el-table-column label="操作" align="center" min-width="120px">
        <template #default="scope">
          <el-button
              link
              type="primary"
              @click="openForm('update', scope.row.id)"
              v-hasPermi="['ecg:job-record:update']"
          >
            编辑
          </el-button>
          <el-button
              link
              type="danger"
              @click="handleDelete(scope.row.id)"
              v-hasPermi="['ecg:job-record:delete']"
          >
            删除
          </el-button>
        </template>
      </el-table-column>
-->
    </el-table>
    <!-- 分页 -->
    <Pagination
        :total="total"
        v-model:page="queryParams.pageNo"
        v-model:limit="queryParams.pageSize"
        @pagination="getList"
    />
  </ContentWrap>

</template>

<script setup lang="ts">
import {defineComponent, PropType} from "vue";
import { DevRentApi, DevRentVO } from '@/api/ecg/devrent'
import {QueueVO} from "@/api/ecg/queue";
import {isStringEmpty} from "@/utils/stringUtil";
import {dateFormatter, timeFormatter} from "@/utils/formatTime";
import {JobRecordApi, JobRecordVO} from "@/api/ecg/jobrecord";

/** 装机拆机 表单 */
defineComponent({ name: 'DevInstallPanel' })

const emit = defineEmits(['success']) // 定义 success 事件，用于操作成功后的回调

const { t } = useI18n() // 国际化
const message = useMessage() // 消息弹窗

const dialogVisible = ref(false) // 弹窗的是否展示

const formLoading = ref(false) // 表单的加载中：1）修改时的数据加载；2）提交的按钮禁用
const formType = ref('create') // 表单的类型：create - 新增；update - 修改

const patient = ref<QueueVO>({
  patId: '',
  patName: ''
})

const formData = ref({
  id: undefined,
  devId: undefined,
  patId: patient.value?.patId,
  patName: patient.value?.patName,
  rentTime: new Date().getTime(),
  returnTime: undefined,
  interference: undefined,
  baseline: undefined,
  detachment: undefined,
  remark: undefined
})
const formRules = reactive({
  devId: [{ required: true, message: '设备编号不能为空', trigger: 'blur' }],
  rentTime: [{ required: true, message: '请选择装机日期', trigger: 'blur' }],
  patId: [{ required: true, message: '目前没有患者', trigger: 'blur' }],
  patName: [{ required: true, message: '目前没有患者', trigger: 'blur' }]
})
const formRef = ref() // 表单 Ref

/** 提交表单 */
const submitForm = async () => {
  // 校验表单
  await formRef.value.validate()
  // 提交请求
  formLoading.value = true
  try {
    const data = formData.value as unknown as DevRentVO
    if (formData.value.id === null || formData.value.id === undefined) {
      const result = await DevRentApi.devInstall(data)
      formData.value.id = result
      message.success(t('新建成功'))
    } else {
      await DevRentApi.devInstall(data)
      message.success(t('更新成功'))
    }
    dialogVisible.value = false
    // 发送操作成功的事件
    emit('success')
    resetForm()
    getList()
  } finally {
    formLoading.value = false
  }
}

const cancelInstall = async () => {
  const data = formData.value as unknown as DevRentVO
  if (formData.value.id === null || formData.value.id === undefined) {
    const result = await DevRentApi.devCancel(data)
    formData.value.id = result
    message.success(t('操作成功'))
  } else {
    await DevRentApi.devCancel(data)
    message.success(t('操作成功'))
  }
  // 发送操作成功的事件
  emit('success')
  resetForm()
  getList()
}

/** 重置表单 */
const resetForm = () => {
  formData.value = {
    id: undefined,
    devId: undefined,
    patId: patient.value?.patId,
    patName: patient.value?.patName,
    rentTime: new Date().getTime(),
    returnTime: undefined,
    interference: undefined,
    baseline: undefined,
    detachment: undefined,
    remark: undefined
  }
  formRef.value?.resetFields()
}

const setPatient = (queueVO: QueueVO | undefined) => {
  patient.value = queueVO
  resetForm()
}
defineExpose({ setPatient }) // 提供 setPatient 方法，用于设置患者


const loading = ref(true) // 列表的加载中
const list = ref<JobRecordVO[]>([]) // 列表的数据
const total = ref(0) // 列表的总页数
const queryParams = reactive({
  pageNo: 1,
  pageSize: 10,
  jobType: 0,
  docId: undefined,
  docName: undefined,
  devId: undefined,
  patId: undefined,
  patName: undefined,
  jobTime: [],
  summary: undefined,
  remark: undefined,
  createTime: []
})
/** 查询列表 */
const getList = async () => {
  loading.value = true
  try {
    const data = await JobRecordApi.getJobRecordDoctorPage(queryParams)
    list.value = data.list
    total.value = data.total
  } finally {
    loading.value = false
  }
}

const onCurChange = (cur) => {
  if (cur !== null)
    getSelectedRent( cur.rentId )
}

const getSelectedRent = async (rentId) => {
  formData.value = await DevRentApi.getDevRent(rentId)
}

/** 初始化 **/
onMounted(() => {
  getList()
})

</script>

